@@ -160,7 +160,7 @@ class Layout(ABC):
         if not widget._nodes:
             width = 0
         else:
-            arrangement = widget._arrange(Size(container.width, 0))
+            arrangement = widget._arrange(Size(0, 0))
             return arrangement.total_region.right
         return width
 
