@@ -266,7 +266,7 @@ class DataTable(ScrollView, Generic[CellType], can_focus=True):
         background: $surface ;
         color: $text;
         height: auto;
-        max-height: 100vh;
+        max-height: 100%;
     }
     DataTable > .datatable--header {
         text-style: bold;
